@@ -3,7 +3,7 @@ package Plack::Middleware::XSRFBlock;
 {
   $Plack::Middleware::XSRFBlock::DIST = 'Plack-Middleware-XSRFBlock';
 }
-$Plack::Middleware::XSRFBlock::VERSION = '0.0.18';
+$Plack::Middleware::XSRFBlock::VERSION = '0.0.19';
 use strict;
 use warnings;
 use parent 'Plack::Middleware';
@@ -89,7 +89,7 @@ sub detect_xsrf {
     # We can say for certain that if we don't have the header_name set
     # it's a missing form parameter
     # If it is set ... well, either could be missing
-    if (not defined $val and not length $val) {
+    if (!defined $val || !length $val) {
         # no X- headers expected
         return 'form field missing'
             if not defined $self->header_name;
@@ -394,7 +394,7 @@ Plack::Middleware::XSRFBlock - Block XSRF Attacks with minimal changes to your a
 
 =head1 VERSION
 
-version 0.0.18
+version 0.0.19
 
 =head1 SYNOPSIS
 
@@ -725,7 +725,7 @@ Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Chisel Wright.
+This software is copyright (c) 2023 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
